##################################################################################################
#	This code and associated data files reproduce the analyses described in Vitousek et al.		 #
#	"The lingering impact of stress: brief acute glucorticoid exposure has sustained, dose-		 #
#	dependent effects on reproduction."															 #
#	Code was written by Conor Taff. 															 #
#	Last updated 7 May 2018. Last run in R v 3.3.3. 											 #
#	Note that several packages must be installed prior to running and supporting data files must #
#	be accessible in the working directory. Also note that some analyses presented in the paper  #
# 	require changing options below to reproduce (for example, some analyses are presented with   #
#	or without a covariate and there are options embedded in the code below to choose).          #
#	Several plots use random jittering for points, so exact output will differ slightly.			 #
##################################################################################################

##################################################################################################
##################################################################################################
## SECTION 1. Validation of cort dosing protocol.												##
##################################################################################################
##################################################################################################

## Load libraries used for plotting
	library(scales)

## Read in the data to be used for this section.
	# 'Input_Dosing_Validation' has cort levels after testing doses and capture intervals.
	# 'Input_Natural_Cort_Variation' has cort levels from a large set of unmanipulated birds.
	d<-read.csv("Input_Dosing_Validation.csv")
	d2<-read.csv("Input_Natural_Cort_Variation.csv")
	
## Set up some objects needed for plotting
	d$Int<-as.numeric(d$Interval)
	r<-rep(c(30,90,180),4)
	t<-c(rep("High",3),rep("Low",3),rep("Long",3),rep("DMSO",3))
	x<-rep(NA,length(r))
	data<-data.frame(r,t,x)
	d$Int.r<-d$Interval+runif(nrow(d),-3,3)
	
	for(i in 1:nrow(data)){
		sub<-subset(d,as.character(d$Dose)==as.character(data$t[i])
			& as.numeric(d$Int)==as.numeric(data$r[i]))
		data$x[i]<-mean(sub$Cort)
	}
	
	for(i in 1:nrow(d)){
		if(d$Dose[i]=="DMSO"){d$Int.f[i]<-d$Int[i]-4.5}
		if(d$Dose[i]=="Low"){d$Int.f[i]<-d$Int[i]-1.5}
		if(d$Dose[i]=="High"){d$Int.f[i]<-d$Int[i]+1.5}
		if(d$Dose[i]=="Long"){d$Int.f[i]<-d$Int[i]+4.5}
	}
	d$Int.f<-d$Int.f+runif(nrow(d),-1.5,1.5)
	
## Make the plot
	pdf("Output_Validation.pdf",width=8.3,height=5.9)
	
	plot(data$r,data$x,type="n",xlab="           Time after first dose (min)",ylab="Corticosterone (ng/mL)",
		main="Corticosterone Dosing Validation",xlim=c(0,185),ylim=c(0,250),
		xaxp=c(0,180,6),cex.lab=1.3,cex.main=1.5)

		points(subset(d$Int.f,d$Dose=="High"),subset(d$Cort,d$Dose=="High"),pch=21,bg=alpha("red",0.6))
		points(subset(d$Int.f,d$Dose=="DMSO"),subset(d$Cort,d$Dose=="DMSO"),pch=21,bg=alpha("gray40",0.6))
		points(subset(d$Int.f,d$Dose=="Low"),subset(d$Cort,d$Dose=="Low"),pch=21,bg=alpha("orange",0.6))
		points(subset(d$Int.f,d$Dose=="Long"),subset(d$Cort,d$Dose=="Long"),pch=21,bg=alpha("slateblue",0.6))
		
		dmso30<-sd(subset(d$Cort,d$Dose=="DMSO"&d$Interval==30))/sqrt(length(subset(d$Cort,d$Dose=="DMSO"&d$Interval==30)))
		dmso90<-sd(subset(d$Cort,d$Dose=="DMSO"&d$Interval==90))/sqrt(length(subset(d$Cort,d$Dose=="DMSO"&d$Interval==90)))
		dmso180<-sd(subset(d$Cort,d$Dose=="DMSO"&d$Interval==180))/sqrt(length(subset(d$Cort,d$Dose=="DMSO"&d$Interval==180)))
		
		high30<-sd(subset(d$Cort,d$Dose=="High"&d$Interval==30))/sqrt(length(subset(d$Cort,d$Dose=="High"&d$Interval==30)))
		high90<-sd(subset(d$Cort,d$Dose=="High"&d$Interval==90))/sqrt(length(subset(d$Cort,d$Dose=="High"&d$Interval==90)))
		high180<-sd(subset(d$Cort,d$Dose=="High"&d$Interval==180))/sqrt(length(subset(d$Cort,d$Dose=="High"&d$Interval==180)))
		
		low30<-sd(subset(d$Cort,d$Dose=="Low"&d$Interval==30))/sqrt(length(subset(d$Cort,d$Dose=="Low"&d$Interval==30)))
		low90<-sd(subset(d$Cort,d$Dose=="Low"&d$Interval==90))/sqrt(length(subset(d$Cort,d$Dose=="Low"&d$Interval==90)))
		low180<-sd(subset(d$Cort,d$Dose=="Low"&d$Interval==180))/sqrt(length(subset(d$Cort,d$Dose=="Low"&d$Interval==180)))
		
		long30<-sd(subset(d$Cort,d$Dose=="Long"&d$Interval==30))/sqrt(length(subset(d$Cort,d$Dose=="Long"&d$Interval==30)))
		long90<-sd(subset(d$Cort,d$Dose=="Long"&d$Interval==90))/sqrt(length(subset(d$Cort,d$Dose=="Long"&d$Interval==90)))
		long180<-sd(subset(d$Cort,d$Dose=="Long"&d$Interval==180))/sqrt(length(subset(d$Cort,d$Dose=="Long"&d$Interval==180)))
		
		lines(rep(30,2),c(data[10,3]+dmso30,data[10,3]-dmso30),col="gray40",lwd=2)
		lines(rep(90,2),c(data[11,3]+dmso90,data[11,3]-dmso90),col="gray40",lwd=2)
		lines(rep(180,2),c(data[12,3]+dmso180,data[12,3]-dmso180),col="gray40",lwd=2)
		
		lines(rep(30,2),c(data[1,3]+high30,data[1,3]-high30),col="red",lwd=2)
		lines(rep(90,2),c(data[2,3]+high90,data[2,3]-high90),col="red",lwd=2)
		lines(rep(180,2),c(data[3,3]+high180,data[3,3]-high180),col="red",lwd=2)
		
		lines(rep(30,2),c(data[4,3]+low30,data[4,3]-low30),col="orange",lwd=2)
		lines(rep(90,2),c(data[5,3]+low90,data[5,3]-low90),col="orange",lwd=2)
		lines(rep(180,2),c(data[6,3]+low180,data[6,3]-low180),col="orange",lwd=2)
		
		lines(rep(30,2),c(data[7,3]+long30,data[7,3]-long30),col="slateblue",lwd=2)
		lines(rep(90,2),c(data[8,3]+long90,data[8,3]-long90),col="slateblue",lwd=2)
		lines(rep(180,2),c(data[9,3]+long180,data[9,3]-long180),col="slateblue",lwd=2)
		
		text(32,data[4,3]+4,"*",cex=1.5)
		text(32,data[7,3]-4,"*",cex=1.5)
		text(34,data[1,3]+4,"**",cex=1.5)
		text(94,data[8,3]+4,"**",cex=1.5)	
			
		groups<-c("DMSO","Low","High","Long")
		colors<-c("gray40","orange","red","slateblue")
		for(i in 1:4){
			sub<-subset(data,data$t==groups[i])
			lines(sub$r,sub$x,lwd=2,col=colors[i])
		}
		
		legend("topright",groups,lwd=2,col=colors,cex=1.3,bty="n")
		
		boxplot(x=d2$Basecort,range=0,add=TRUE,boxwex=12,at=3,col="gray40",lty=1)
		boxplot(x=d2$Stresscort,range=0,add=TRUE,boxwex=12,at=26,col="gray40",lty=1)

		arrows(0,-67,0,-47,xpd=TRUE,lwd=2,col="darkgreen",len=.1)
		arrows(60,-67,60,-47,xpd=TRUE,lwd=2,col="darkgreen",len=.1)
		
	dev.off()
	
## Clear workspace before moving to next section
	rm(list=ls())
	
##################################################################################################
##################################################################################################
## SECTION 2. Testing for effects on nestling phenotype.										##
##################################################################################################
##################################################################################################
		
## Load libraries to be used
	library(plyr)
	library(dplyr)
	library(lme4)
	library(lmerTest)
	library(MuMIn)

## Load data to be used and make some column manipulations
	d<-read.csv("Input_Adult_Phenotype.csv")
	d<-subset(d,is.na(d$max.brood)==FALSE)
	d$UnitBox<-paste(d$unit,d$box,sep="")
	d<-d[,c("UnitBox","max.brood","n.fledged","ci.jdate","treatment")]
	colnames(d)<-c("UnitBox","Max.Brood","N.Fledged","CI.Date","Treatment")

## Make a new object that has a row for each nestling rather than each nest
	tres.surv<-as.data.frame(matrix(nrow=(sum(d$Max.Brood)),ncol=3))
	colnames(tres.surv)<-c("Subject","Fledged","UnitBox")

# Make a new vector to name chicks with generic ids unique within each nest
	Names<-c("Chick1","Chick2","Chick3","Chick4","Chick5","Chick6","Chick7")
	
## Fill in some data to the nestling survival data frame from the adult data frame.
	counter<-1
	for(i in 1:nrow(d)){
		tres.surv$UnitBox[counter:(counter+d$Max.Brood[i]-1)]<-rep(d$UnitBox[i],d$Max.Brood[i])
		tres.surv$Subject[counter:(counter+d$Max.Brood[i]-1)]<-Names[1:(d$Max.Brood[i])]
		tres.surv$Fledged[counter:(counter+d$Max.Brood[i]-1)]<-c(rep(1,d$N.Fledged[i]),
			rep(0,d$Max.Brood[i]-d$N.Fledged[i]))
		counter<-counter+d$Max.Brood[i]
	}

## Scale variables to mean of 0 and unit variance
	d$Max.Brood<-scale(d$Max.Brood)
	d$N.Fledged<-scale(d$N.Fledged)
	d$CI.Date<-scale(d$CI.Date)
	
## Join the nestling level data to adult data to get CI date, treatment, and max brood
	tres.surv<-join(tres.surv,d,"UnitBox")

## The set of candidate models to fit to nestling fledging data
	modlist<-c("Fledged~1+(1|UnitBox)",
		"Fledged~CI.Date+Max.Brood+(1|UnitBox)",
		"Fledged~CI.Date+Max.Brood+Treatment+(1|UnitBox)",
		"Fledged~CI.Date+Max.Brood+Treatment+Max.Brood*Treatment+(1|UnitBox)",
		"Fledged~Treatment+(1|UnitBox)")

## Fit candidate models
	m1<-glmer(as.formula(modlist[1]),data=tres.surv,family=binomial)
	m2<-glmer(as.formula(modlist[2]),data=tres.surv,family=binomial)
	m3<-glmer(as.formula(modlist[3]),data=tres.surv,family=binomial)
	m4<-glmer(as.formula(modlist[4]),data=tres.surv,family=binomial)
	m5<-glmer(as.formula(modlist[5]),data=tres.surv,family=binomial)
	
## Add fit models to a list
	mod.output<-list(m1,m2,m3,m4,m5)
	mod.output2<-list(summary(m1),summary(m2),summary(m3),summary(m4),summary(m5))
		
## Build an AIC table
		AICtab<-as.data.frame(modlist)
		for(j in 1:nrow(AICtab)){
			AICtab$AICc[j]<-AICc(mod.output[[j]])
			AICtab$LL[j]<-logLik(mod.output[[j]])
			AICtab$K[j]<-attr(logLik(mod.output[[j]]),"df")
		}
		minim<-min(AICtab$AICc)
		AICtab$D.AICc<-AICtab$AICc-minim
		AICtab$rellik<-exp(-.5* AICtab$D.AICc)
		sumAICs<-sum(AICtab$rellik)
		for(u in 1:nrow(AICtab)){
			AICtab$Wi[u]<-round(AICtab$rellik[u]/sumAICs,2)
		}
		AICtab<-AICtab[order(-AICtab$rellik),]
		
## Write the output to a file
	write.csv(AICtab,"Output_Nestling_Surv_AIC_Tab.csv")
	sink("Output_Nestling_Surv_Fit_Mods.txt")
		mod.output2
	sink()		
	
## Detach libraries used in this section
	detach("package:lmerTest",unload=TRUE)
	detach("package:MuMIn",unload=TRUE)
		
##################################################################################################
##################################################################################################
## SECTION 3. Testing for effects on adult phenotype.											##
##################################################################################################
##################################################################################################		
		
## Load in some libraries to be used in this analysis
	# Not all of these are used in current version of code
		pkg<-c("plyr","lme4","AICcmodavg","pbkrtest","bbmle","nlme","rethinking","MuMIn","lmerTest","coefplot","MASS","gridExtra","sjPlot")
		for(i in 1:length(pkg)){library(pkg[i],character.only=TRUE)}
		
## Read in the data
		d<-read.csv("Input_Adult_Phenotype.csv")
		
## Candidate model set for adult phenotype responses
		modlist<-c("resp~1",
			"resp~Initial",
			"resp~treatment+Initial",
			"resp~ci.jdate+max.brood+Initial",
			"resp~ci.jdate+max.brood+Initial+treatment",
			"resp~ci.jdate+max.brood+Initial+treatment+treatment*max.brood")
			
## Check for pre-treatment differences in base, clutch size, stress, dex

	sink("Output_Pre_treatment_Diffs.txt")
		summary(lm(d$inc.base~d$treatment))
		anova(lm(d$inc.base~d$treatment))
		summary(lm(d$inc.str~d$treatment))
		anova(lm(d$inc.str~d$treatment))
		summary(lm(d$inc.str.resp~d$treatment))
		anova(lm(d$inc.str.resp~d$treatment))
		summary(lm(d$inc.fback~d$treatment))
		anova(lm(d$inc.fback~d$treatment))
		summary(lm(d$conditionhb1~d$treatment))
		anova(lm(d$conditionhb1~d$treatment))
		summary(lm(d$clutch.size~d$treatment))
		anova(lm(d$clutch.size~d$treatment))
	sink()
			
## Make separate data objects for each response variable
		d.cond<-na.omit(d[,c("conditionhb1","conditionhb2","treatment","ci.jdate","max.brood")])
		d.base<-na.omit(d[,c("inc.base","prov.base","treatment","ci.jdate","max.brood")])
		d.induce<-na.omit(d[,c("inc.str","prov.str","treatment","ci.jdate","max.brood")])
		d.strresp<-na.omit(d[,c("inc.str.resp","prov.str.resp","treatment","ci.jdate","max.brood")])
		d.dexresp<-na.omit(d[,c("inc.fback","prov.fback","treatment","ci.jdate","max.brood")])
		d.baserom<-na.omit(d[,c("pre.rom","post.rom","treatment","ci.jdate","max.brood")])
		d.baseoxy<-na.omit(d[,c("pre.oxy","post.oxy","treatment","ci.jdate","max.brood")])
		d.mass<-na.omit(d[,c("mass1","mass2","treatment","ci.jdate","max.brood")])
		
		d.base$prov.base<-log(d.base$prov.base+1)
		d.induce$prov.str<-log(d.induce$prov.str)
		d.strresp$prov.str.resp<-log(d.strresp$prov.str.resp+150)
		d.dexresp$prov.fback<-log(d.dexresp$prov.fback+150)
		
		data.list<-list(d.cond,d.mass,d.base,d.induce,d.strresp,d.dexresp,d.baserom,d.baseoxy)

## List of the response variables for object naming
	resps<-c("Condition","Mass","Basecort","Induced","StrResp","DexResp","BaseROM","BaseOXY")

## Rename response variables to 'initial' and 'resp' in each case
	for(i in 1:length(data.list)){
		colnames(data.list[[i]])<-c("Initial","resp","treatment","ci.jdate","max.brood")	
	}
		
## Fit candidate model set to each response variable
	for(k in 1:length(data.list)){
		mod.output<-list()
		mod.output2<-list()
			for(i in 1:length(modlist)){
				dat<-data.list[[k]]
				model<-paste("fig.mod",i,sep="_")
				mod<-lm(as.formula(modlist[i]),data=dat)
				assign(model[1],mod)
				mod.output[[i]]<-get(model)
				mod.output2[[i]]<-summary(get(model))
			}
		AICtab<-as.data.frame(modlist)
		for(j in 1:nrow(AICtab)){
			AICtab$AICc[j]<-AICc(mod.output[[j]])
			AICtab$LL[j]<-logLik(mod.output[[j]])
			AICtab$K[j]<-attr(logLik(mod.output[[j]]),"df")
		}
		minim<-min(AICtab$AICc)
		AICtab$D.AICc<-AICtab$AICc-minim
		AICtab$rellik<-exp(-.5* AICtab$D.AICc)
		sumAICs<-sum(AICtab$rellik)
		for(u in 1:nrow(AICtab)){
			AICtab$Wi[u]<-round(AICtab$rellik[u]/sumAICs,2)
		}
		AICtab<-AICtab[order(-AICtab$rellik),]
		assign(paste("AIC.",resps[k],sep=""),AICtab)
		assign(paste("mods.",resps[k],sep=""),mod.output)
		assign(paste("mods.s.",resps[k],sep=""),mod.output2)
	}
	
## Make a list of all the AICc tables for each response variable
	AIC.tabs<-rbind(AIC.Condition,AIC.Mass,AIC.Basecort,AIC.Induced,AIC.StrResp,AIC.DexResp,AIC.BaseROM,AIC.BaseOXY)
	AIC.tabs$Response<-c(rep("Condition",6),rep("Mass",6),rep("Basecort",6),
		rep("Induced",6),rep("StrResp",6),rep("DexResp",6),
		rep("BaseROM",6),rep("BaseOXY",6))
	write.csv(AIC.tabs,"Output_All_AIC_Tables.csv")
	
## Make a list of all the models to label the outputs
	formulas<-c(gsub("resp","Condition",modlist),gsub("resp","Mass",modlist),
		gsub("resp","Basecort",modlist),gsub("resp","Induced",modlist),
		gsub("resp","StrResp",modlist),gsub("resp","DexResp",modlist),
		gsub("resp","BaseROM",modlist),gsub("resp","BaseOXY",modlist))	
	
## Make list of all fit models and output to csv file
	Mod.outputs<-c(mods.s.Condition,mods.s.Mass,mods.s.Basecort,mods.s.Induced,mods.s.StrResp,
		mods.s.DexResp,mods.s.BaseROM,mods.s.BaseOXY)
	for(i in 1:length(formulas)){
		Mod.outputs[[i]][1]<-formulas[i]
	}
	sink("Output_Adult_Pheno_Fit_Models.txt")
		Mod.outputs
	sink()

## Candidate models for adult survival data	
	modlist<-c("resp~1",
			"resp~conditionhb1",
			"resp~conditionhb1+ci.jdate+clutch.size",
			"resp~treatment",
			"resp~ci.jdate+clutch.size",
			"resp~ci.jdate+clutch.size+treatment",
			"resp~ci.jdate+clutch.size+treatment+treatment*clutch.size")
			
## Response variables
	resp<-c("abd.inc","return.n1","Return.No.Abandoners")
			
## Make data sets for abandonment and for survival
	d.abd<-d[,c("abd.inc","conditionhb1","treatment","ci.jdate","clutch.size")]
	colnames(d.abd)[1]<-"resp"
	d.abd<-na.omit(d.abd)
	d.abd$resp<-gsub("N",0,d.abd$resp)
	d.abd$resp<-gsub("Y",1,d.abd$resp)
	d.abd$resp<-as.numeric(d.abd$resp)

	d.surv<-d[,c("return.n1","conditionhb1","treatment","ci.jdate","clutch.size")]
	colnames(d.surv)[1]<-"resp"
	d.surv<-na.omit(d.surv)
	d.surv$resp<-gsub("N",0,d.surv$resp)
	d.surv$resp<-gsub("Y",1,d.surv$resp)
	d.surv$resp<-as.numeric(d.surv$resp)
	
	data.list<-list(d.abd,d.surv)

## Fit candidate model set to each response variable
	for(k in 1:length(data.list)){
		mod.output<-list()
		mod.output2<-list()
			for(i in 1:length(modlist)){
				dat<-data.list[[k]]
				model<-paste("fig.mod",i,sep="_")
				mod<-glm(as.formula(modlist[i]),data=dat,family=binomial)
				assign(model[1],mod)
				mod.output[[i]]<-get(model)
				mod.output2[[i]]<-summary(get(model))
			}
		AICtab<-as.data.frame(modlist)
		for(j in 1:nrow(AICtab)){
			AICtab$AICc[j]<-AICc(mod.output[[j]])
			AICtab$LL[j]<-logLik(mod.output[[j]])
			AICtab$K[j]<-attr(logLik(mod.output[[j]]),"df")
		}
		minim<-min(AICtab$AICc)
		AICtab$D.AICc<-AICtab$AICc-minim
		AICtab$rellik<-exp(-.5* AICtab$D.AICc)
		sumAICs<-sum(AICtab$rellik)
		for(u in 1:nrow(AICtab)){
			AICtab$Wi[u]<-round(AICtab$rellik[u]/sumAICs,2)
		}
		AICtab<-AICtab[order(-AICtab$rellik),]
		assign(paste("AIC.",resp[k],sep=""),AICtab)
		assign(paste("mods.",resp[k],sep=""),mod.output)
		assign(paste("mods.s.",resp[k],sep=""),mod.output2)
	}	
		
## Make a list of all the AICc tables for each response variable
	AIC.tabs<-rbind(AIC.abd.inc,AIC.return.n1)
	AIC.tabs$Response<-c(rep("Abandoned_In_Inc",7),rep("Survived_Next_Year",7))
	write.csv(AIC.tabs,"Output_Surv_Abd_AIC_Table.csv")
	
## Make a list of all the models to label the outputs
	formulas<-c(gsub("resp","Abandoned",modlist),gsub("resp","Survived_Next",modlist))	
	
## Make list of all fit models and output to csv file
	Mod.outputs<-c(mods.s.abd.inc,mods.s.return.n1)
	for(i in 1:length(formulas)){
		Mod.outputs[[i]][1]<-formulas[i]
	}
	sink("Output_Adult_Surv_Abd_Fit_Models.txt")
		Mod.outputs
	sink()
				
################### REPEAT OF ABOVE BUT USING DELTA VALUES

## Candidate model set for adult phenotype responses
		modlist<-c("resp~1",
			"resp~treatment",
			"resp~ci.jdate+max.brood+treatment",
			"resp~ci.jdate+max.brood+treatment+treatment*max.brood")
			
## Make separate data objects for each response variable
		d.base<-na.omit(d[,c("inc.base","prov.base","treatment","ci.jdate","max.brood")])
		d.induce<-na.omit(d[,c("inc.str","prov.str","treatment","ci.jdate","max.brood")])
		d.strresp<-na.omit(d[,c("inc.str.resp","prov.str.resp","treatment","ci.jdate","max.brood")])
		d.dexresp<-na.omit(d[,c("inc.fback","prov.fback","treatment","ci.jdate","max.brood")])
		
		d.base$Delta<-d.base$prov.base-d.base$inc.base
		d.induce$Delta<-d.induce$prov.str-d.induce$inc.str
		d.strresp$Delta<-d.strresp$prov.str.resp-d.strresp$inc.str.resp
		d.dexresp$Delta<-d.dexresp$prov.fback-d.dexresp$inc.fback
		
		d.base$Delta<-log(d.base$Delta+10)
		d.induce$Delta<-log(d.induce$Delta+50)
		d.strresp$Delta<-log(d.strresp$Delta+150)
		d.dexresp$Delta<-log(d.dexresp$Delta+150)
		
		data.list<-list(d.base,d.induce,d.strresp,d.dexresp)

## List of the response variables for object naming
	resps<-c("Basecort","Induced","StrResp","DexResp")

## Rename response variables to 'initial' and 'resp' in each case
	for(i in 1:length(data.list)){
		colnames(data.list[[i]])<-c("Initial","Post","treatment","ci.jdate","max.brood","resp")	
	}
		
## Fit candidate model set to each response variable
	for(k in 1:length(data.list)){
		mod.output<-list()
		mod.output2<-list()
			for(i in 1:length(modlist)){
				dat<-data.list[[k]]
				model<-paste("fig.mod",i,sep="_")
				mod<-lm(as.formula(modlist[i]),data=dat)
				assign(model[1],mod)
				mod.output[[i]]<-get(model)
				mod.output2[[i]]<-summary(get(model))
			}
		AICtab<-as.data.frame(modlist)
		for(j in 1:nrow(AICtab)){
			AICtab$AICc[j]<-AICc(mod.output[[j]])
			AICtab$LL[j]<-logLik(mod.output[[j]])
			AICtab$K[j]<-attr(logLik(mod.output[[j]]),"df")
		}
		minim<-min(AICtab$AICc)
		AICtab$D.AICc<-AICtab$AICc-minim
		AICtab$rellik<-exp(-.5* AICtab$D.AICc)
		sumAICs<-sum(AICtab$rellik)
		for(u in 1:nrow(AICtab)){
			AICtab$Wi[u]<-round(AICtab$rellik[u]/sumAICs,2)
		}
		AICtab<-AICtab[order(-AICtab$rellik),]
		assign(paste("AIC.",resps[k],sep=""),AICtab)
		assign(paste("mods.",resps[k],sep=""),mod.output)
		assign(paste("mods.s.",resps[k],sep=""),mod.output2)
	}
	
## Make a list of all the AICc tables for each response variable
	AIC.tabs<-rbind(AIC.Basecort,AIC.Induced,AIC.StrResp,AIC.DexResp)
	AIC.tabs$Response<-c(rep("Basecort",4),
		rep("Induced",4),rep("StrResp",4),rep("DexResp",4)
		)
	write.csv(AIC.tabs,"Output_Adult_Pheno_AIC_Tables_Deltas.csv")
	
## Make a list of all the models to label the outputs
	formulas<-c(
		gsub("resp","delBasecort",modlist),gsub("resp","delInduced",modlist),
		gsub("resp","delStrResp",modlist),gsub("resp","delDexResp",modlist))	
	
## Make list of all fit models and output to csv file
	Mod.outputs<-c(mods.s.Basecort,mods.s.Induced,mods.s.StrResp,
		mods.s.DexResp)
	for(i in 1:length(formulas)){
		Mod.outputs[[i]][1]<-formulas[i]
	}
	sink("Output_Adult_Pheno_Fit_Models_Deltas.txt")
		Mod.outputs
	sink()

########## run with max brood size rather than clutch size


## Candidate models for adult survival data	
	modlist<-c("resp~1",
			"resp~conditionhb1",
			"resp~conditionhb1+ci.jdate+max.brood",
			"resp~treatment",
			"resp~ci.jdate+max.brood",
			"resp~ci.jdate+max.brood+treatment",
			"resp~ci.jdate+max.brood+treatment+treatment*max.brood")
d.save<-d
for(i in 1:nrow(d)){
	ifelse(is.na(d$max.brood[i]),d$max.brood2[i]<-0,d$max.brood2[i]<-d$max.brood[i])
}	
d$max.brood<-as.numeric(d$max.brood2)

## Response variables
	resp<-c("abd.inc","return.n1","Return.No.Abandoners")
			
## Make data sets for abandonment and for survival
	d.abd<-d[,c("abd.inc","conditionhb1","treatment","ci.jdate","max.brood")]
	colnames(d.abd)[1]<-"resp"
	d.abd<-na.omit(d.abd)
	d.abd$resp<-gsub("N",0,d.abd$resp)
	d.abd$resp<-gsub("Y",1,d.abd$resp)
	d.abd$resp<-as.numeric(d.abd$resp)

	d.surv<-d[,c("return.n1","conditionhb1","treatment","ci.jdate","max.brood")]
	colnames(d.surv)[1]<-"resp"
	d.surv<-na.omit(d.surv)
	d.surv$resp<-gsub("N",0,d.surv$resp)
	d.surv$resp<-gsub("Y",1,d.surv$resp)
	d.surv$resp<-as.numeric(d.surv$resp)
	
	data.list<-list(d.abd,d.surv)

## Fit candidate model set to each response variable
	for(k in 1:length(data.list)){
		mod.output<-list()
		mod.output2<-list()
			for(i in 1:length(modlist)){
				dat<-data.list[[k]]
				model<-paste("fig.mod",i,sep="_")
				mod<-glm(as.formula(modlist[i]),data=dat,family=binomial)
				assign(model[1],mod)
				mod.output[[i]]<-get(model)
				mod.output2[[i]]<-summary(get(model))
			}
		AICtab<-as.data.frame(modlist)
		for(j in 1:nrow(AICtab)){
			AICtab$AICc[j]<-AICc(mod.output[[j]])
			AICtab$LL[j]<-logLik(mod.output[[j]])
			AICtab$K[j]<-attr(logLik(mod.output[[j]]),"df")
		}
		minim<-min(AICtab$AICc)
		AICtab$D.AICc<-AICtab$AICc-minim
		AICtab$rellik<-exp(-.5* AICtab$D.AICc)
		sumAICs<-sum(AICtab$rellik)
		for(u in 1:nrow(AICtab)){
			AICtab$Wi[u]<-round(AICtab$rellik[u]/sumAICs,2)
		}
		AICtab<-AICtab[order(-AICtab$rellik),]
		assign(paste("AIC.",resp[k],sep=""),AICtab)
		assign(paste("mods.",resp[k],sep=""),mod.output)
		assign(paste("mods.s.",resp[k],sep=""),mod.output2)
	}	
		
## Make a list of all the AICc tables for each response variable
	AIC.tabs<-rbind(AIC.abd.inc,AIC.return.n1)
	AIC.tabs$Response<-c(rep("Abandoned_In_Inc",7),rep("Survived_Next_Year",7))
	write.csv(AIC.tabs,"Output_Adult_Surv_Abd_AIC_Table_Maxbrood.csv")
	
## Make a list of all the models to label the outputs
	formulas<-c(gsub("resp","Abandoned",modlist),gsub("resp","Survived_Next",modlist))	
	
## Make list of all fit models and output to csv file
	Mod.outputs<-c(mods.s.abd.inc,mods.s.return.n1)
	for(i in 1:length(formulas)){
		Mod.outputs[[i]][1]<-formulas[i]
	}
	sink("Output_Adult_Surv_Abd_Fit_Models_Maxbrood.txt")
		Mod.outputs
	sink()		
		
############# modified female survival models to be for total # fledged instead

## Candidate models for adult survival data	
	modlist<-c("n.fledged ~1",
			"n.fledged ~conditionhb1",
			"n.fledged ~conditionhb1+ci.jdate+clutch.size",
			"n.fledged ~treatment",
			"n.fledged ~ci.jdate+clutch.size",
			"n.fledged ~ci.jdate+clutch.size+treatment",
			"n.fledged ~ci.jdate+clutch.size+treatment+treatment*clutch.size")
			
## Response variables
	resp<-c("n.fledged")
			
## Make data sets for abandonment and for survival
	d.flg<-d[,c("n.fledged","conditionhb1","treatment","ci.jdate","clutch.size")]
	d.flg <-na.omit(d.flg)
	
	data.list<-list(d.flg)

## Fit candidate model set to each response variable
	for(k in 1:length(data.list)){
		mod.output<-list()
		mod.output2<-list()
			for(i in 1:length(modlist)){
				dat<-data.list[[k]]
				model<-paste("fig.mod",i,sep="_")
				mod<-glm(as.formula(modlist[i]),data=dat,family=poisson)
				assign(model[1],mod)
				mod.output[[i]]<-get(model)
				mod.output2[[i]]<-summary(get(model))
			}
		AICtab<-as.data.frame(modlist)
		for(j in 1:nrow(AICtab)){
			AICtab$AICc[j]<-AICc(mod.output[[j]])
			AICtab$LL[j]<-logLik(mod.output[[j]])
			AICtab$K[j]<-attr(logLik(mod.output[[j]]),"df")
		}
		minim<-min(AICtab$AICc)
		AICtab$D.AICc<-AICtab$AICc-minim
		AICtab$rellik<-exp(-.5* AICtab$D.AICc)
		sumAICs<-sum(AICtab$rellik)
		for(u in 1:nrow(AICtab)){
			AICtab$Wi[u]<-round(AICtab$rellik[u]/sumAICs,2)
		}
		AICtab<-AICtab[order(-AICtab$rellik),]
		assign(paste("AIC.",resp[k],sep=""),AICtab)
		assign(paste("mods.",resp[k],sep=""),mod.output)
		assign(paste("mods.s.",resp[k],sep=""),mod.output2)
	}	
		
## Make a list of all the AICc tables for each response variable
	AIC.tabs<-rbind(AIC.n.fledged)
	AIC.tabs$Response<-c(rep("NumFledged",7))
	write.csv(AIC.tabs,"Output_Num_Fled_AIC_Table.csv")
	
## Make a list of all the models to label the outputs
	formulas<-rep("NumFledged",7)
	
## Make list of all fit models and output to csv file
	Mod.outputs<-c(mods.s.n.fledged)
	for(i in 1:length(formulas)){
		Mod.outputs[[i]][1]<-formulas[i]
	}
	sink("Output_Num_Fled_Fit_Models.txt")
		Mod.outputs
	sink()
	
## Detach some packages before next section	
		detach("package:lmerTest",unload=TRUE)
		detach("package:MuMIn",unload=TRUE)	

##################################################################################################
##################################################################################################
## SECTION 4. Temperature during incubation from HOBO loggers.									##
##################################################################################################
##################################################################################################
		
## Load in some libraries to be used in this analysis
	# Not all of these are used in current version of code
		pkg<-c("plyr","lme4","pbkrtest","bbmle","nlme","rethinking","MuMIn","lmerTest","coefplot","MASS","gridExtra","sjPlot")
		for(i in 1:length(pkg)){library(pkg[i],character.only=TRUE)}

## Read in the data files that will be used for this code. These files should be 
	# provided in the working directory.
		d<-read.csv("Input_Daily_Egg_Temp_Data.csv") 	# The main data file. Bout characterstics by nest/day.
		w<-read.csv("Input_Ithaca_Weather.csv")			# Weather data from local weather station.
		t<-read.csv("Input_Adult_Phenotype.csv")			# Nest level characteristics.
		j<-read.csv("Input_JDates.csv")					# Reference file to convert to julian dates.
		
## Make some modifications to the data files to get them in a useable format
		t<-subset(t,t$band!="2631-13727")		# Remove this bird that does not match a HOBO record.
		w[is.na(w$Precip)==TRUE,c("Precip")]<-0	# Clean up weather data missing values.

## Make a new object that has weather variables for each date
		j.w<-as.data.frame(unique(w$Date))
		colnames(j.w)<-c("Date")
		j.w<-join(j.w,j,"Date")
		for(i in 1:nrow(j.w)){
			temp<-subset(w,w$Date==j.w$Date[i])
			j.w$MaxTemp[i]<-max(temp$Temp,na.rm=TRUE)
			j.w$LowTemp[i]<-min(temp$Temp,na.rm=TRUE)
			j.w$Precip[i]<-sum(temp$Precip,na.rm=TRUE)
			temp2<-subset(temp,temp$Hour>6&temp$Hour<22)
			j.w$AvgTemp[i]<-mean(temp2$Temp,na.rm=TRUE)
		}
		j.w$TempSwing<-j.w$MaxTemp-j.w$LowTemp
		colnames(j.w)<-c("Date","jdate",colnames(j.w)[3:length(colnames(j.w))])

# Join the weather object to the main dataframe.
		d<-join(d,j.w,"jdate")
		t$unitbox<-paste(as.numeric(t$unit),t$box,sep="_")
		d<-join(d,t,"unitbox")

# Set up a categorical variable for pre (A), during (B), and post (C) treatment
		d$offset2<-rep(NA,nrow(d))
		d[d$offset<7,c("offset2")]<-"A"
		d[d$offset>6 & d$offset<13,c("offset2")]<-"B"
		d[d$offset>12,c("offset2")]<-"C"
		d$offset2<-as.factor(d$offset2)

# Exclude nests that had protracted abandonments and thus weird egg temperature data.
	# Can try running the analysis with and without these birds.
		d<-subset(d,d$unitbox!="2_80")   # Try with and without this, early failure
		d<-subset(d,d$unitbox!="2_51")   # Try with and without this, early failure
		d<-subset(d,d$unitbox!="2_8") 	 # should be excluded, not in rfid data
		d<-subset(d,d$unitbox!="2_125")  # failed in incubation

# Make a subset of data from during the treatment period.
		db<-subset(d,d$offset2=="B")
		db<-subset(db,is.na(db$clutch)==FALSE)
		db$length.day.on.min<-log(db$length.day.on.min)
		db$length.day.off.min<-log(db$length.day.off.min)
		db$length.night.on.min<-log(db$length.night.on.min)
		db$length.night.off.min<-log(db$length.night.off.min)
		db.on200.d<-subset(db,db$length.day.on.min<223)  	# Remove extreme outliers for day on bout length
		db.on200.n<-subset(db,db$length.night.on.min<348)	# Remove extreme outliers for night on bout length
		
## Make a candidate model set for these response variables
	modlist<-c("resp~jdate+AvgTemp+clutch+offset+(1|unitbox)",
		"resp~jdate+AvgTemp+clutch+offset+treatment+(1|unitbox)",
		"resp~treatment+(1|unitbox)",
		"resp~jdate+AvgTemp+clutch+offset+treatment+treatment*offset+(1|unitbox)",
		"resp~1+(1|unitbox)")
		
## List of response variables to be fit to candidate model set
	resps<-c("length.day.on.min","length.day.off.min","avg.range.day.on","temp.day.on","pct.on.day",
		"length.night.on.min","length.night.off.min","avg.range.night.off","temp.night.on","pct.on.night")
		
## List the dataframes to be used for each response variable. Most are the same, but for length of day and night
	# on bouts we have removed extreme outliers that were likely from timwes where nests were in process of being
	# abandoned or something was wrong with HOBO (because it is unrealistic to have some long on bouts).
	datalist<-c("db.on200.d",rep("db",4),"db.on200.n",rep("db",4))

## Fit candidate model set to each response variable
	for(k in 1:length(resps)){
		modlist2<-gsub("resp",resps[k],modlist)
			mod.output<-list()
			for(i in 1:length(modlist2)){
				dat<-get(datalist[k])
				model<-paste("fit.mod",i,sep="_")
				mod<-lmer(as.formula(modlist2[i]),data=dat)
				assign(model[1],mod)
				mod.output[[i]]<-get(model)
			}
		AICtab<-as.data.frame(modlist2)
		for(j in 1:nrow(AICtab)){
			AICtab$AICc[j]<-AICc(mod.output[[j]])
			AICtab$LL[j]<-logLik(mod.output[[j]])
			AICtab$K[j]<-attr(logLik(mod.output[[j]]),"df")
		}
		minim<-min(AICtab$AICc)
		AICtab$D.AICc<-AICtab$AICc-minim
		AICtab$rellik<-exp(-.5* AICtab$D.AICc)
		sumAICs<-sum(AICtab$rellik)
		for(u in 1:nrow(AICtab)){
			AICtab$Wi[u]<-round(AICtab$rellik[u]/sumAICs,2)
		}
		AICtab<-AICtab[order(-AICtab$rellik),]
		assign(paste("AIC.",resps[k],sep=""),AICtab)
		assign(paste("mods.",resps[k],sep=""),mod.output)
	}
	
## Make a list of all the AICc tables for each response variable
	AIC.tabs<-rbind(AIC.length.day.on.min,AIC.length.day.off.min,AIC.avg.range.day.on,AIC.temp.day.on,AIC.pct.on.day,
		AIC.length.night.on.min,AIC.length.night.off.min,AIC.avg.range.night.off,AIC.temp.night.on,AIC.pct.on.night)
	write.csv(AIC.tabs,"Output_EggTemp_All_AIC_Tables.csv")		
		
##################################################################################################
##################################################################################################
## SECTION 5. Feeding rate from RFID records.													##
##################################################################################################
##################################################################################################		
		
	############# *******************
		# This string indicates places that the code needs to be switched to run either
		# females controlling for male feeding rate OR all females without male rate
		# in the models. The sample size is larger for the second because not all males
		# had PIT tags and even in cases where males did have PIT tags they weren't 
		# always deployed until partway through the season. 

## Set whether to run on nests with male feeding or on all females
	############# *******************	
		choose<-0 		# 1 = all females, 0 = including male feeding rate
	############# *******************

## Load libraries to be used [note some not used in most recent version]
		library(lme4)
		library(bbmle)
		library(nlme)
		library(rethinking)
		library(MuMIn)
		library(lmerTest)
		library(coefplot)
		library(gridExtra)
		library(pbkrtest)
		library(MASS)
		library(sjPlot)

# Read in the data
	d<-read.csv("Input_Hourly_Feeding_Data.csv")		# The main data set
	d<-subset(d,d$broodsize>0)		# Excluding some obs after nests failed

# Making a lookup column to allow matching (not sure if this is actually used anywhere anymore?)
	d$temporary<-paste(d$lookup,d$nestlingage,sep="-")

# Excluding nests that we don't want in the dataset, these failed early and were weird
	d<-subset(d,d$lookup!="CU2-80")
	d<-subset(d,d$lookup!="CU2-51")

# Subsetting the data that will be used because we want complete records for AIC
	if(choose==0){d<-d[,c("juliandate","hour","broodsize","nestlingage","count","matecount","rfid","treatment","temp","flatwing1",
			"ci.jdate")]}
	if(choose==1){d<-d[,c("juliandate","hour","broodsize","nestlingage","count","rfid","treatment","temp","flatwing1",
			"ci.jdate")]}
	d<-subset(d,d$temp>1)	# gets rid of obs with errors for temperature or missing value codes
	d<-subset(d,d$hour<21)	# gets rid of obs when rfid should not have been on but was for some reason
	
# Set na action so that it will fail if NAs are included
	options(na.action=na.fail)
	
# Remove all data rows that don't have complete records to make AIC work
	d<-na.omit(d)

# Make a log count column, not sure this is used anymore
	d$lcount<-log(d$count)

# Standardize quantitative columns to have mean 0 and SD 1
	d$s.hour<-(d$hour-mean(d$hour))/sd(d$hour)
	d$s.temp<-(d$temp-mean(d$temp))/sd(d$temp)
	d$s.ci.jdate<-(d$ci.jdate-mean(d$ci.jdate))/sd(d$ci.jdate)
	d$s.broodsize<-(d$broodsize-mean(d$broodsize))/sd(d$broodsize)
	d$s.nestlingage<-(d$nestlingage-mean(d$nestlingage))/sd(d$nestlingage)
	d$s.count<-(d$lcount-mean(d$lcount))/sd(d$lcount)
	if(choose==0){d$s.m.count<-(d$matecount-mean(d$matecount))/sd(d$matecount)} # Turn on for males

# Model lists for the two options
	mod.choose0<-c("count~s.temp+s.ci.jdate+s.broodsize+I(s.broodsize^2)+s.nestlingage+I(s.nestlingage^2)+s.hour+
			I(s.hour^2)+s.m.count+s.broodsize*s.nestlingage+(1|rfid)",
		"count~s.temp+s.ci.jdate+s.broodsize+I(s.broodsize^2)+s.nestlingage+I(s.nestlingage^2)+s.hour+I(s.hour^2)+
				s.m.count+treatment+s.broodsize*s.nestlingage+(1|rfid)",
		"count~s.temp+s.ci.jdate+s.broodsize+I(s.broodsize^2)+s.nestlingage+I(s.nestlingage^2)+s.hour+I(s.hour^2)+
				s.m.count+treatment+treatment*s.broodsize+treatment*I(s.broodsize^2)+s.broodsize*s.nestlingage+(1|rfid)",
		"count~s.temp+s.ci.jdate+s.broodsize+I(s.broodsize^2)+s.nestlingage+I(s.nestlingage^2)+s.hour+I(s.hour^2)+
				s.m.count+treatment+treatment*s.nestlingage+treatment*I(s.nestlingage^2)+s.broodsize*s.nestlingage+(1|rfid)",
		"count~s.temp+s.ci.jdate+s.broodsize+I(s.broodsize^2)+s.nestlingage+I(s.nestlingage^2)+s.hour+I(s.hour^2)+
				s.m.count+treatment+treatment*s.nestlingage+treatment*I(s.nestlingage^2)+treatment*s.broodsize+
				treatment*I(s.broodsize^2)+s.broodsize*s.nestlingage+(1|rfid)",
		"count~nestlingage+I(nestlingage^2)+broodsize+I(broodsize^2)+(1|rfid)",
		"count~1+(1|rfid)")
	mod.choose1<-c("count~s.temp+s.ci.jdate+s.broodsize+I(s.broodsize^2)+s.nestlingage+I(s.nestlingage^2)+
			s.hour+I(s.hour^2)+s.broodsize*s.nestlingage+(1|rfid)",
		"count~s.temp+s.ci.jdate+s.broodsize+I(s.broodsize^2)+s.nestlingage+I(s.nestlingage^2)+
				s.hour+I(s.hour^2)+treatment+s.broodsize*s.nestlingage+(1|rfid)",
		"count~s.temp+s.ci.jdate+s.broodsize+I(s.broodsize^2)+s.nestlingage+I(s.nestlingage^2)+
				s.hour+I(s.hour^2)+treatment+treatment*s.broodsize+treatment*I(s.broodsize^2)+s.broodsize*s.nestlingage+(1|rfid)",
		"count~s.temp+s.ci.jdate+s.broodsize+I(s.broodsize^2)+s.nestlingage+I(s.nestlingage^2)+
				s.hour+I(s.hour^2)+treatment+treatment*s.nestlingage+treatment*I(s.nestlingage^2)+s.broodsize*s.nestlingage+(1|rfid)",
		"count~s.temp+s.ci.jdate+s.broodsize+I(s.broodsize^2)+s.nestlingage+I(s.nestlingage^2)+
				s.hour+I(s.hour^2)+treatment+treatment*s.nestlingage+treatment*I(s.nestlingage^2)+treatment*s.broodsize+treatment*I(s.broodsize^2)+
				s.broodsize*s.nestlingage+(1|rfid)",
		"count~nestlingage+I(nestlingage^2)+broodsize+I(broodsize^2)+(1|rfid)",
		"count~1+(1|rfid)")


# Read in list of models to be fit. Choose one set to be used and gray out others.
		if(choose==0){mods<-mod.choose0}
		if(choose==0){name<-"females_control_males"}
		if(choose==1){mods<-mod.choose1}
		if(choose==1){name<-"females_no_males"}
	
## Loop through model list and fit each model, saving fit model as object in a list
	mod.output<-list()
	for(i in 1:length(mods)){
		model<-paste("fit.mod",i,sep="_")
		mod<-glmer(as.formula(mods[i]),family=poisson,data=d)
		assign(model[1],mod)
		mod.output[[i]]<-get(model)
	}
	
# Create AIC table based on the loop of models above
		AICtab<-as.data.frame(mods)
		for(i in 1:nrow(AICtab)){
			AICtab$AICc[i]<-AICc(mod.output[[i]])
			AICtab$LL[i]<-logLik(mod.output[[i]])
			AICtab$K[i]<-attr(logLik(mod.output[[i]]),"df")
		}
		minim<-min(AICtab$AICc)
		AICtab$D.AICc<-AICtab$AICc-minim
		AICtab$rellik<-exp(-.5* AICtab$D.AICc)
		sumAICs<-sum(AICtab$rellik)
		for(i in 1:nrow(AICtab)){
			AICtab$Wi[i]<-round(AICtab$rellik[i]/sumAICs,2)
		}
		AICtab<-AICtab[order(-AICtab$rellik),]
		
# write the AIC table to a csv file
		write.csv(AICtab,paste("Output_Feeding_Rate_AIC_",name,".csv",sep=""))

# The best model to be used for plotting below
	if(choose==0){
		cont.males<-glmer(count ~ s.temp + s.ci.jdate + s.broodsize + I(s.broodsize^2) + s.nestlingage + 
			I(s.nestlingage^2) + s.hour + I(s.hour^2) + s.m.count + treatment + treatment*s.nestlingage +
			treatment*I(s.nestlingage^2) + treatment*s.broodsize + treatment*I(s.broodsize^2) + 
			s.broodsize*s.nestlingage + (1|rfid), data=d, family=poisson)
		}
	if(choose==0){sjt.glmer(cont.males,file="Output_Best_Feed_Mod_Control_Males.html",
		emph.p=TRUE,show.se=TRUE,show.header=TRUE,show.re.var=TRUE,
		show.aicc=TRUE,show.dev=TRUE)}		
	if(choose==1){
		all.females<-glmer(count ~ s.temp + s.ci.jdate + s.broodsize + I(s.broodsize^2) + s.nestlingage + 
			I(s.nestlingage^2) + s.hour + I(s.hour^2) + treatment + treatment*s.nestlingage +
			treatment*I(s.nestlingage^2) + treatment*s.broodsize + treatment*I(s.broodsize^2) + 
			s.broodsize*s.nestlingage + (1|rfid), data=d, family=poisson)
		}
	if(choose==1){sjt.glmer(all.females,file="Output_Best_Feed_Mod_All_Females.html",
		emph.p=TRUE,show.se=TRUE,show.header=TRUE,show.re.var=TRUE,
		show.aicc=TRUE,show.dev=TRUE,separate.ci.col=TRUE)}	
	if(choose==1){mod<-all.females}  
	if(choose==0){mod<-cont.males}
	
## Plot some diagnostics from the model
	pdf(paste("Output_Model_Diagnostic_Plots_",name,".pdf",sep=""),width=8,height=8)
		par(mfrow=c(2,2))
		qqnorm(resid(mod),main="normal qq-plot, residuals",col=col.alpha("slateblue",0.1),pch=16)
		qqline(resid(mod),lwd=2)
		
		qqnorm(ranef(mod)$rfid[,1])
		qqline(ranef(mod)$rfid[,1])
		
		plot(fitted(mod),resid(mod),col=col.alpha("slateblue",0.1),pch=16)
		abline(h=0,col="black",lwd=2)
		
		d$fitted<-fitted(mod)
		plot(d$fitted,jitter(d$count,0.1),col=col.alpha("slateblue",0.1),pch=16)
		abline(0,1,lwd=2,col="black")
	dev.off()

#######################################################################
## Code below here is all for drawing plots from model chosen above  ##
#######################################################################
	
## Generate some numbers used for making plots
	fixie<-fixef(mod)
	hour<-(12-mean(d$hour))/sd(d$hour)				## sets hour to noon
	temp<-(65-mean(d$temp))/sd(d$temp)				## sets temperature to 65 degrees
	age<-mean(d$s.nestlingage)						## sets nestling age to mean
	brood<-mean(d$s.broodsize)						## sets brood size to mean
	cidate<-(135-mean(d$ci.jdate))/sd(d$ci.jdate)	## sets ci date to 135
	if(choose==0){malecount<-mean(d$s.m.count)}		## average male feeding rate

## Draw sample from the posterior distribution of the model to use for plotting
	number<-100000  		# Set the number of samples drawn for plotting (higher = smoother but takes longer)
	post<-mvrnorm(number,fixef(mod),vcov(mod))
	post<-as.data.frame(post)
	r<-seq(-4,4,0.2)  	# sequence of values that model will be evaluated over 

## Varying Brood size in two panels. Note that depending on the model chosen, some parameters from 'post' need
## to be manually turned on or off below (specifically, 's.m.count' for models without male feeding rate).
		pdf(paste("Output_Model_Plot_",name,".pdf",sep=""),width=9,height=4.5)
		par(mfrow=c(1,2))
		Set.Brood1<-c((4-mean(d$broodsize))/sd(d$broodsize),(6-mean(d$broodsize))/sd(d$broodsize))  # set to plot broods of 4 & 6
		Broods<-c("Brood Size 4","Brood Size 6")
		for(i in 1:2){
		Set.Brood<-Set.Brood1[i]
		mu.control<-sapply(r,function(z)mean(exp(
			post$"(Intercept)" +
			post$"s.temp"*temp +
			post$"s.ci.jdate"*cidate +
			post$"s.broodsize"*Set.Brood + 
			post$"I(s.broodsize^2)"*(Set.Brood^2) +
			post$"s.nestlingage"*z +
			post$"I(s.nestlingage^2)"*(z^2) +
			post$"s.hour"*hour +
			post$"I(s.hour^2)"*(hour^2) +
			############# *******************	
				post$"s.m.count"*malecount + 
			############# *******************	
			post$"s.broodsize:s.nestlingage"*Set.Brood*z)))
		ci.control<-sapply(r,function(z)HPDI(exp(
			post$"(Intercept)" +
			post$"s.temp"*temp +
			post$"s.ci.jdate"*cidate +
			post$"s.broodsize"*Set.Brood + 
			post$"I(s.broodsize^2)"*(Set.Brood^2) +
			post$"s.nestlingage"*z +
			post$"I(s.nestlingage^2)"*(z^2) +
			post$"s.hour"*hour +
			post$"I(s.hour^2)"*(hour^2) +
			############# *******************	
				post$"s.m.count"*malecount +
			############# *******************	
			post$"s.broodsize:s.nestlingage"*Set.Brood*z)))
			
		mu.dmso<-sapply(r,function(z)mean(exp(
			post$"(Intercept)" +
			post$"treatmentDMSO" +
			post$"s.broodsize:treatmentDMSO"*Set.Brood +
			post$"I(s.broodsize^2):treatmentDMSO"*(Set.Brood^2) +
			post$"s.nestlingage:treatmentDMSO"*z +
			post$"I(s.nestlingage^2):treatmentDMSO"*(z^2) +
			post$"s.temp"*temp +
			post$"s.ci.jdate"*cidate +
			post$"s.broodsize"*Set.Brood + 
			post$"I(s.broodsize^2)"*(Set.Brood^2) +
			post$"s.nestlingage"*z +
			post$"I(s.nestlingage^2)"*(z^2) +
			post$"s.hour"*hour +
			post$"I(s.hour^2)"*(hour^2) +
			############# *******************	
				post$"s.m.count"*malecount +
			############# *******************
			post$"s.broodsize:s.nestlingage"*Set.Brood*z)))
		ci.dmso<-sapply(r,function(z)HPDI(exp(
			post$"(Intercept)" +
			post$"treatmentDMSO" +
			post$"s.broodsize:treatmentDMSO"*Set.Brood +
			post$"I(s.broodsize^2):treatmentDMSO"*(Set.Brood^2) +
			post$"s.nestlingage:treatmentDMSO"*z +
			post$"I(s.nestlingage^2):treatmentDMSO"*(z^2) +
			post$"s.temp"*temp +
			post$"s.ci.jdate"*cidate +
			post$"s.broodsize"*Set.Brood + 
			post$"I(s.broodsize^2)"*(Set.Brood^2) +
			post$"s.nestlingage"*z +
			post$"I(s.nestlingage^2)"*(z^2) +
			post$"s.hour"*hour +
			post$"I(s.hour^2)"*(hour^2) +
			############# *******************	
				post$"s.m.count"*malecount +
			############# *******************
			post$"s.broodsize:s.nestlingage"*Set.Brood*z)))
			
		mu.high<-sapply(r,function(z)mean(exp(
			post$"(Intercept)" +
			post$"treatmentHigh" +
			post$"s.broodsize:treatmentHigh"*Set.Brood +
			post$"I(s.broodsize^2):treatmentHigh"*(Set.Brood^2) +
			post$"s.nestlingage:treatmentHigh"*z +
			post$"I(s.nestlingage^2):treatmentHigh"*(z^2) +
			post$"s.temp"*temp +
			post$"s.ci.jdate"*cidate +
			post$"s.broodsize"*Set.Brood + 
			post$"I(s.broodsize^2)"*(Set.Brood^2) +
			post$"s.nestlingage"*z +
			post$"I(s.nestlingage^2)"*(z^2) +
			post$"s.hour"*hour +
			post$"I(s.hour^2)"*(hour^2) +
			############# *******************	
				post$"s.m.count"*malecount +
			############# *******************
			post$"s.broodsize:s.nestlingage"*Set.Brood*z)))
		ci.high<-sapply(r,function(z)HPDI(exp(
			post$"(Intercept)" +
			post$"treatmentHigh" +
			post$"s.broodsize:treatmentHigh"*Set.Brood +
			post$"I(s.broodsize^2):treatmentHigh"*(Set.Brood^2) +
			post$"s.nestlingage:treatmentHigh"*z +
			post$"I(s.nestlingage^2):treatmentHigh"*(z^2) +
			post$"s.temp"*temp +
			post$"s.ci.jdate"*cidate +
			post$"s.broodsize"*Set.Brood + 
			post$"I(s.broodsize^2)"*(Set.Brood^2) +
			post$"s.nestlingage"*z +
			post$"I(s.nestlingage^2)"*(z^2) +
			post$"s.hour"*hour +
			post$"I(s.hour^2)"*(hour^2) +
			############# *******************	
				post$"s.m.count"*malecount +
			############# *******************
			post$"s.broodsize:s.nestlingage"*Set.Brood*z)))
			
		mu.long<-sapply(r,function(z)mean(exp(
			post$"(Intercept)" +
			post$"treatmentLong" +
			post$"s.broodsize:treatmentLong"*Set.Brood +
			post$"I(s.broodsize^2):treatmentLong"*(Set.Brood^2) +
			post$"s.nestlingage:treatmentLong"*z +
			post$"I(s.nestlingage^2):treatmentLong"*(z^2) +
			post$"s.temp"*temp +
			post$"s.ci.jdate"*cidate +
			post$"s.broodsize"*Set.Brood + 
			post$"I(s.broodsize^2)"*(Set.Brood^2) +
			post$"s.nestlingage"*z +
			post$"I(s.nestlingage^2)"*(z^2) +
			post$"s.hour"*hour +
			post$"I(s.hour^2)"*(hour^2) +
			############# *******************	
				post$"s.m.count"*malecount +
			############# *******************
			post$"s.broodsize:s.nestlingage"*Set.Brood*z)))
		ci.long<-sapply(r,function(z)HPDI(exp(
			post$"(Intercept)" +
			post$"treatmentLong" +
			post$"s.broodsize:treatmentLong"*Set.Brood +
			post$"I(s.broodsize^2):treatmentLong"*(Set.Brood^2) +
			post$"s.nestlingage:treatmentLong"*z +
			post$"I(s.nestlingage^2):treatmentLong"*(z^2) +
			post$"s.temp"*temp +
			post$"s.ci.jdate"*cidate +
			post$"s.broodsize"*Set.Brood + 
			post$"I(s.broodsize^2)"*(Set.Brood^2) +
			post$"s.nestlingage"*z +
			post$"I(s.nestlingage^2)"*(z^2) +
			post$"s.hour"*hour +
			post$"I(s.hour^2)"*(hour^2) +
			############# *******************	
				post$"s.m.count"*malecount +
			############# *******************
			post$"s.broodsize:s.nestlingage"*Set.Brood*z)))
			
		mu.low<-sapply(r,function(z)mean(exp(
			post$"(Intercept)" +
			post$"treatmentLow" +
			post$"s.broodsize:treatmentLow"*Set.Brood +
			post$"I(s.broodsize^2):treatmentLow"*(Set.Brood^2) +
			post$"s.nestlingage:treatmentLow"*z +
			post$"I(s.nestlingage^2):treatmentLow"*(z^2) +
			post$"s.temp"*temp +
			post$"s.ci.jdate"*cidate +
			post$"s.broodsize"*Set.Brood + 
			post$"I(s.broodsize^2)"*(Set.Brood^2) +
			post$"s.nestlingage"*z +
			post$"I(s.nestlingage^2)"*(z^2) +
			post$"s.hour"*hour +
			post$"I(s.hour^2)"*(hour^2) +
			############# *******************	
				post$"s.m.count"*malecount +
			############# *******************
			post$"s.broodsize:s.nestlingage"*Set.Brood*z)))
		ci.low<-sapply(r,function(z)HPDI(exp(
			post$"(Intercept)" +
			post$"treatmentLow" +
			post$"s.broodsize:treatmentLow"*Set.Brood +
			post$"I(s.broodsize^2):treatmentLow"*(Set.Brood^2) +
			post$"s.nestlingage:treatmentLow"*z +
			post$"I(s.nestlingage^2):treatmentLow"*(z^2) +
			post$"s.temp"*temp +
			post$"s.ci.jdate"*cidate +
			post$"s.broodsize"*Set.Brood + 
			post$"I(s.broodsize^2)"*(Set.Brood^2) +
			post$"s.nestlingage"*z +
			post$"I(s.nestlingage^2)"*(z^2) +
			post$"s.hour"*hour +
			post$"I(s.hour^2)"*(hour^2) +
			############# *******************	
				post$"s.m.count"*malecount +
			############# *******************
			post$"s.broodsize:s.nestlingage"*Set.Brood*z)))
				
					
			r2<-r*sd(d$nestlingage)+mean(d$nestlingage)	
			
			plot(r2,mu.control,type="n",ylim=c(0,35),xlim=c(0,18),
				xlab="Nestling Age",ylab="Feeding Rate",main=Broods[i])
				
			lines(r2,mu.control,lwd=2,col="black")
			shade(ci.control,r2,col=col.alpha("black",0.2))
			lines(r2,mu.dmso,lwd=2,col="gray40")
			shade(ci.dmso,r2,col=col.alpha("gray40",0.2))
			lines(r2,mu.high,lwd=2,col="red")
			shade(ci.high,r2,col=col.alpha("red",0.2))
			lines(r2,mu.long,lwd=2,col="slateblue")
			shade(ci.long,r2,col=col.alpha("slateblue",0.2))
			lines(r2,mu.low,lwd=2,col="orange")
			shade(ci.low,r2,col=col.alpha("orange",0.2))
			abline(v=12,lty=2,col="gray20")
		
			legend("topleft",c("Control","DMSO","Low","High","Long"),
				col=c("black","gray40","orange","red","slateblue"),lwd=2,bty="n")
		}

		dev.off()	
	
	
##################################################################################################
##################################################################################################
## SECTION 6. Activity during incubation.														##
##################################################################################################
##################################################################################################		
	
## Read in the data file

	dd<-read.csv("Input_Incubation_Activity.csv")

## Make some plots of raw data
	pdf("Output_Raw_Inc_Activity_Plots.pdf",width=10,height=5)
	par(mfrow=c(1,4))
	plot(log(dd$TotalReads)~dd$Treatment,ylab="Total Reads",xlab="",las=3)
	plot(log(dd$Thresh.Reads)~dd$Treatment,ylab="Threshold Reads",xlab="",las=3)
	plot(log(dd$Thresh.Dur)~dd$Treatment,ylab="Trip Duration (s)",xlab="",las=3)
	plot(log(dd$Read.Per)~dd$Treatment,ylab="Reads Per Trip",xlab="",las=3)
	dev.off()
	
## Standardize predictor variables in d (helps with fitting)
	dd$T.Day<-scale(dd$T.Day)
	dd$Temp<-scale(dd$Temp)
	dd$Clutch.size<-scale(dd$clutch.size)
	dd$JDate<-as.numeric(dd$JDate)
	dd$JDate<-scale(dd$JDate)
	dd$Thresh.Dur<-as.numeric(gsub("0","1",dd$Thresh.Dur))		
	
## Model list
	modlist<-c("resp~1+(1|Index)+(1|UnitBox)",
		"resp~JDate+Temp+Clutch.size+T.Day+(1|Index)+(1|UnitBox)",
		"resp~JDate+Temp+Clutch.size+T.Day+Treatment+(1|Index)+(1|UnitBox)",
		"resp~JDate+Temp+Clutch.size+T.Day+Treatment+Treatment*Clutch.size+(1|Index)+(1|UnitBox)",
		"resp~JDate+Temp+Clutch.size+T.Day+Treatment+Treatment*T.Day+(1|Index)+(1|UnitBox)",
		"resp~JDate+Temp+Clutch.size+T.Day+Treatment+Treatment*Clutch.size+Treatment*T.Day+(1|Index)+(1|UnitBox)"
		)
		
## List of response variables to be fit
	resps<-c("TotalReads")	
	dd$Index<-seq(1,nrow(dd),1)
	
## Fit candidate models to each response variable
	for(k in 1:length(resps)){
		modlist2<-gsub("resp",resps[k],modlist)
		mod.output<-list()
			for(i in 1:length(modlist2)){
				model<-paste("fit.mod",i,sep="_")
				if(k<3){
					mod<-glmer(as.formula(modlist2[i]),data=dd,family=poisson)
					}
				if(k>2){
					mod<-glmer(as.formula(modlist2[i]),data=Visit,family=poisson)
				}
				assign(model[1],mod)
				mod.output[[i]]<-get(model)
			}
		AICtab<-as.data.frame(modlist2)
		for(j in 1:nrow(AICtab)){
			AICtab$AICc[j]<-AICc(mod.output[[j]])
			AICtab$LL[j]<-logLik(mod.output[[j]])
			AICtab$K[j]<-attr(logLik(mod.output[[j]]),"df")
		}
		minim<-min(AICtab$AICc)
		AICtab$D.AICc<-AICtab$AICc-minim
		AICtab$rellik<-exp(-.5* AICtab$D.AICc)
		sumAICs<-sum(AICtab$rellik)
		for(u in 1:nrow(AICtab)){
			AICtab$Wi[u]<-round(AICtab$rellik[u]/sumAICs,2)
		}
		AICtab<-AICtab[order(-AICtab$rellik),]
		assign(paste("AIC.",resps[k],sep=""),AICtab)
		assign(paste("mods.",resps[k],sep=""),mod.output)
		print(paste(k," of ",length(resps),sep=""))
	}


## Plot of total reads
	j<-dd
	j$Treatment<-relevel(j$Treatment,ref="long")
	j$Treatment<-relevel(j$Treatment,ref="high")
	j$Treatment<-relevel(j$Treatment,ref="low")
	j$Treatment<-relevel(j$Treatment,ref="dmso")
	j$Treatment<-relevel(j$Treatment,ref="control")
	pdf("Output_TotalReads_Inc_Activity.pdf",width=5,height=6.5)
		plot(j$Treatment,j$TotalReads,ylab="Daily time at box entrance (seconds)")
	dev.off()
		
## Make a list of all the AIC tables for each response variable
	#AIC.tabs<-rbind(AIC.TotalReads,AIC.Thresh.Reads,AIC.VisitReads,AIC.Duration)
	write.csv(AICtab,"Output_RFID_Activity_AIC.csv")	
	
## Plot some diagnostics for each best model
	pdf("Output_Inc_Activity_Diagnostic_Plots_.pdf",width=8,height=8)
		models<-list(mods.TotalReads[[3]],mods.TotalReads[[4]])
		yys<-list(dd$TotalReads,dd$TotalReads)
		for(i in 1:2){
			mod<-models[i]
			par(mfrow=c(2,2))
			qqnorm(resid(mod[[1]]),main="normal qq-plot, residuals",col=col.alpha("slateblue",0.4),pch=16)
			qqline(resid(mod[[1]]),lwd=2)
			
			qqnorm(ranef(mod[[1]])$UnitBox[,1])
			qqline(ranef(mod[[1]])$UnitBox[,1])
			
			plot(fitted(mod[[1]]),resid(mod[[1]]),col=col.alpha("slateblue",0.4),pch=16)
			abline(h=0,col="black",lwd=2)
			
			dd$fitted<-fitted(mod[[1]])
			plot(dd$fitted,yys[[i]],col=col.alpha("slateblue",0.4),pch=16)
			abline(0,1,lwd=2,col="black")
		}
	dev.off()	
	
### Save best model output
	
	sink("Output_RFID_Activity_Fit_Mods.txt")
		summary(mods.TotalReads[[3]])
		summary(mods.TotalReads[[4]])
	sink()
	
## Make plots of model predicted treatment groups	
	mod<-mods.TotalReads[[3]]
	library(MASS)
	post<-as.data.frame(mvrnorm(10000,mu=fixef(mod),Sigma=vcov(mod)))	

	trts<-c("control","dmso","low","high","long")
	mus<-c(
		mean(exp(post$"(Intercept)")),
		mean(exp(post$"(Intercept)"+post$Treatmentdmso)),
		mean(exp(post$"(Intercept)"+post$Treatmenthigh)),
		mean(exp(post$"(Intercept)"+post$Treatmentlong)),
		mean(exp(post$"(Intercept)"+post$Treatmentlow))
	)
	cis<-c(
		HPDI(exp(post$"(Intercept)"),prob=0.9),
		HPDI(exp(post$"(Intercept)"+post$Treatmentdmso),prob=0.9),
		HPDI(exp(post$"(Intercept)"+post$Treatmenthigh),prob=0.9),
		HPDI(exp(post$"(Intercept)"+post$Treatmentlong),prob=0.9),
		HPDI(exp(post$"(Intercept)"+post$Treatmentlow),prob=0.9)
	)

	cil<-cis[c(1,3,5,7,9)]
	cih<-cis[c(2,4,6,8,10)]
	
	modfits<-t(as.data.frame(rbind(trts,mus,cil,cih)))
	rownames(modfits)<-c("A","B","C","D","E")
	modfits<-as.data.frame(modfits)
	modfits$mus<-as.numeric(as.character(modfits$mus))
	modfits$cil<-as.numeric(as.character(modfits$cil))
	modfits$cih<-as.numeric(as.character(modfits$cih))
	
	
## Define a function to draw half violin plot. 
	## Function sourced from github "dgrtwo/geom_flat_violin.R
	## https://gist.github.com/dgrtwo/ebtwo/eb7750e74997891d7c20#file-geom_flat_violin-r
	
	library("tidyverse")
	library("ggplot2")
	library("dplyr")
		
			"%||%" <- function(a, b) {		
		  if (!is.null(a)) a else b		
		}						
		geom_flat_violin <- function(mapping = NULL, data = NULL, stat = "ydensity",		
		                        position = "dodge", trim = TRUE, scale = "area",		
		                        show.legend = NA, inherit.aes = TRUE, ...) {		
		  layer(		
		    data = data,		
		    mapping = mapping,		
		    stat = stat,		
		    geom = GeomFlatViolin,		
		    position = position,		
		    show.legend = show.legend,		
		    inherit.aes = inherit.aes,		
		    params = list(		
		      trim = trim,	
		      scale = scale,		
		      ...		
		    )		
		  )		
		}
		GeomFlatViolin <-		
		  ggproto("GeomFlatViolin", Geom,
				          setup_data = function(data, params) {		
		            data$width <- data$width %||%		
		              params$width %||% (resolution(data$x, FALSE) * 0.9)
		            data %>%		
		              group_by(group) %>%		
		              mutate(ymin = min(y),		
		                     ymax = max(y),		
		                     xmin = x,		
		                     xmax = x + width / 2)				            		
		          },
		          draw_group = function(data, panel_scales, coord) {		
		            data <- transform(data, xminv = x,		
		                              xmaxv = x + violinwidth * (xmax - x))		
		            newdata <- rbind(plyr::arrange(transform(data, x = xminv), y),		
		                             plyr::arrange(transform(data, x = xmaxv), -y))		
		            newdata <- rbind(newdata, newdata[1,])				            		
		            ggplot2:::ggname("geom_flat_violin", GeomPolygon$draw_panel(newdata, panel_scales, coord))		
		          },				          		
		          draw_key = draw_key_polygon,				          		
		          default_aes = aes(weight = 1, colour = "grey20", fill = "white", size = 0.5,		
		                            alpha = NA, linetype = "solid"),				         		
		          required_aes = c("x", "y")		
		)
	
### Make the half violin plot

	pdf("Output_Half_Violin.pdf",width=5,height=6.3)
	levels(j$Treatment)<-c("control","dmso","low","high","long")
	levels(modfits$trts)<-c("control","dmso","low","high","long")
	modfits$Treatment<-modfits$trts
	ggplot(data = j, 
	       mapping = aes(x = Treatment, y = TotalReads, fill = Treatment)) + 
	  geom_flat_violin(scale = "count", trim = FALSE) + 
	  scale_fill_manual(values=c("black","gray40","orange","red","slateblue"))+
	  scale_y_continuous(expand=c(0,0),limits=c(0,6500))+
	  geom_dotplot(binaxis = "y",dotsize = 0.5, stackdir = "down", binwidth = 100, 
	               position = position_nudge(-0.025)) + 
	  geom_segment(mapping=aes(x=1.3,xend=1.3,y=707,yend=1331))+
	  geom_segment(mapping=aes(x=2.3,xend=2.3,y=379,yend=792))+
	  geom_segment(mapping=aes(x=3.3,xend=3.3,y=386,yend=713))+
	  geom_segment(mapping=aes(x=4.3,xend=4.3,y=284,yend=508))+
	  geom_segment(mapping=aes(x=5.3,xend=5.3,y=414,yend=734))+
	  geom_point(data=modfits, shape = 22,size = 4,color="black", fill=c("black","gray40","orange","red","slateblue"),
	  	mapping = aes(x = c(1.3,2.3,3.3,4.3,5.3), y = mus)) +
	  theme(panel.grid.major=element_blank(),panel.grid.minor=element_blank(),
	  	panel.background=element_blank(),axis.line=element_line(color="black"),legend.position="none") + 
	  labs(x = "Treatment", y = "Daily time at nest entrance (seconds)")
	  
	dev.off() 

##################################################################################################
##################################################################################################
## SECTION 7. Nestling phenotype.																##
##################################################################################################
##################################################################################################	

### Load in libraries to be used (may not all be necessary)
	library(lme4)
	library(lmerTest)
	library(rethinking)
	library(MASS)
	library(MuMIn)

## Read in the dataa file
	d<-read.csv("Input_Nestling_Phenotypes.csv")

# This saves an unaltered version of the data so that data can be subseted for each subseqent analysis.
	# Because models are compared by AIC, each subset has to be made with complete data and different
	# nestlings are missing different response variables. So the exact data-set for each candidate model
	# set can differ slightly below.
		d2<-d

## List of models in candidate set
	modlist.l<-c("log(resp)~1+(1|cuniqnest)",
		"log(resp)~N7to18.Temp.X+CI.JDate+Brood.size.d12+(1|cuniqnest)",
		"log(resp)~N7to18.Temp.X+CI.JDate+Brood.size.d12+Treatment+(1|cuniqnest)",
		"log(resp)~N7to18.Temp.X+CI.JDate+Brood.size.d12+Treatment+Brood.size.d12*Treatment+(1|cuniqnest)",
		"log(resp)~Treatment+(1|cuniqnest)")
		
	modlist.1<-c("resp~1+(1|cuniqnest)",
		"resp~N7to18.Temp.X+CI.JDate+Brood.size.d12+(1|cuniqnest)",
		"resp~N7to18.Temp.X+CI.JDate+Brood.size.d12+Treatment+(1|cuniqnest)",
		"resp~N7to18.Temp.X+CI.JDate+Brood.size.d12+Treatment+Brood.size.d12*Treatment+(1|cuniqnest)",
		"resp~Treatment+(1|cuniqnest)")

## List of response variables
	responses<-c("nmass","condition.headbill","nheadbill","nflatwing","Baseline","Stress","StressResp","DexRecovery","DexResp")	

## Fit a set of candidate models to each of 8 response variables
	for(i in 1:length(responses)){
		## Finagle the data to the right response variable
			d<-d2[,c(responses[i],"Treatment","N7to18.Temp.X","CI.JDate","Brood.size.d12","cuniqnest")]
			d<-na.omit(d)
			colnames(d)[1]<-"resp"
			modlist<-modlist.1
			#if(responses[i]=="Baseline"){
			#	d<-subset(d,d$resp<100)
			#}
			if(responses[i]=="Baseline"){
				d$resp<-d$resp+1
				modlist<-modlist.l
			}
			if(responses[i]=="Stress"){
				d$resp<-d$resp+1
				modlist<-modlist.l
			}
			if(responses[i]=="StressResp"){
				d$resp<-d$resp+150
				modlist<-modlist.l
			}
			if(responses[i]=="DexRecovery"){
				d$resp<-d$resp+150
				modlist<-modlist.l
			}
			if(responses[i]=="DexResp"){
				d$resp<-d$resp+150
				modlist<-modlist.l
			}
		## Fit set of candidate models
			mod.output<-list()
			for(k in 1:length(modlist)){
				model<-paste("fit.mod",k,sep="_")
				mod<-lmer(as.formula(modlist[k]),data=d)
				assign(model[1],mod)
				mod.output[[k]]<-get(model)
				}
		## Make an AIC table
			AICtab<-as.data.frame(modlist)
			for(j in 1:nrow(AICtab)){
				AICtab$AICc[j]<-AICc(mod.output[[j]])
				AICtab$LL[j]<-logLik(mod.output[[j]])
				AICtab$K[j]<-attr(logLik(mod.output[[j]]),"df")
			}
			minim<-min(AICtab$AICc)
			AICtab$D.AICc<-AICtab$AICc-minim
			AICtab$rellik<-exp(-.5* AICtab$D.AICc)
			sumAICs<-sum(AICtab$rellik)
			for(u in 1:nrow(AICtab)){
				AICtab$Wi[u]<-round(AICtab$rellik[u]/sumAICs,2)
			}
			AICtab<-AICtab[order(-AICtab$rellik),]
			assign(paste("AICtab.",responses[i],sep=""),AICtab)
			assign(paste("Fitmods.",responses[i],sep=""),mod.output)
	}	
			
## Make a list of all the AICc tables for each response variable
	AIC.tabs<-rbind(AICtab.nmass,AICtab.condition.headbill,AICtab.nheadbill,AICtab.nflatwing,AICtab.Baseline,
		AICtab.Stress,AICtab.StressResp,AICtab.DexRecovery,AICtab.DexResp)
	AIC.tabs$Response<-c(rep("Mass",length(modlist)),rep("Condition",length(modlist)),rep("Headbill",length(modlist)),
		rep("Flatwing",length(modlist)),rep("Baseline",length(modlist)),rep("Stress",length(modlist)),
		rep("StressResp",length(modlist)),
		rep("DexRecovery",length(modlist)),rep("DexResp",length(modlist)))
	write.csv(AIC.tabs,"Output_AIC_All_Nestling_Tables.csv")
	
## Make a list of all the models to label teh outputs
	formulas<-c(gsub("resp","Mass",modlist),gsub("resp","Condition",modlist),gsub("resp","Headbill",modlist),
		gsub("resp","Flatwing",modlist),gsub("resp","Baseline",modlist),gsub("resp","Stress",modlist),
		gsub("resp","StressResp",modlist),
		gsub("resp","DexRecovery",modlist),gsub("resp","DexResp",modlist))
		
## Write the best fit models to a text file for each response
	sink("Output_All_Best_Fit_Mods_Nestlings.txt")
		print("Nestling Mass")
		summary(Fitmods.nmass[[4]])
		
		print("Nestling Condition")
		summary(Fitmods.condition.headbill[[4]])
		summary(Fitmods.condition.headbill[[5]])
		summary(Fitmods.condition.headbill[[1]])
		
		print("Nestling Headbill")
		summary(Fitmods.nheadbill[[1]])
		
		print("Nestling Flatwing")
		summary(Fitmods.nflatwing[[4]])
		
		print("Nestling Baseline")
		summary(Fitmods.Baseline[[4]])
		
		print("Nestling Stress")
		summary(Fitmods.Stress[[4]])
		
		print("Nestling StressResp")
		summary(Fitmods.StressResp[[4]])
		
		print("NestlingDexRecovery")
		summary(Fitmods.DexRecovery[[4]])
		
		print("Nestling Dex Resp")
		summary(Fitmods.DexResp[[4]])
		
	sink()

## Make some variables to be used in plotting
	Avg.Temp<-mean(d2$N7to18.Temp.X)
	Avg.CI<-mean(d2$CI.JDate)
	brood.r<-seq(2,6,1)
	num<-100000
			
### Write a function to make plots for nestling results
	plot.n<-function(mod,num=100000,BROOD=brood.r,y.low=0,y.high=100,ylaber="Response",mainer="Title",XLIM=c(4,6)){
		post<-mvrnorm(num,fixef(mod),vcov(mod))
		post<-as.data.frame(post)
		mu.Control<-sapply(BROOD,function(z)mean(post$"(Intercept)"+
			post$N7to18.Temp.X*Avg.Temp+post$CI.JDate*Avg.CI+post$"Brood.size.d12"*z))
		ci.Control<-sapply(BROOD,function(z)HPDI(post$"(Intercept)"+
			post$N7to18.Temp.X*Avg.Temp+post$CI.JDate*Avg.CI+post$Brood.size.d12*z))	
		mu.DMSO<-sapply(BROOD,function(z)mean(post$"(Intercept)"+
			post$N7to18.Temp.X*Avg.Temp+post$CI.JDate*Avg.CI+post$Brood.size.d12*z+
			post$TreatmentDMSO+post$"Brood.size.d12:TreatmentDMSO"*z))
		ci.DMSO<-sapply(BROOD,function(z)HPDI(post$"(Intercept)"+
			post$N7to18.Temp.X*Avg.Temp+post$CI.JDate*Avg.CI+post$Brood.size.d12*z+
			post$TreatmentDMSO+post$"Brood.size.d12:TreatmentDMSO"*z))
		mu.High<-sapply(BROOD,function(z)mean(post$"(Intercept)"+
			post$N7to18.Temp.X*Avg.Temp+post$CI.JDate*Avg.CI+post$Brood.size.d12*z+
			post$TreatmentHIGH+post$"Brood.size.d12:TreatmentHIGH"*z))
		ci.High<-sapply(BROOD,function(z)HPDI(post$"(Intercept)"+
			post$N7to18.Temp.X*Avg.Temp+post$CI.JDate*Avg.CI+post$Brood.size.d12*z+
			post$TreatmentHIGH+post$"Brood.size.d12:TreatmentHIGH"*z))
		mu.Long<-sapply(BROOD,function(z)mean(post$"(Intercept)"+
			post$N7to18.Temp.X*Avg.Temp+post$CI.JDate*Avg.CI+post$Brood.size.d12*z+
			post$TreatmentLONG+post$"Brood.size.d12:TreatmentLONG"*z))
		ci.Long<-sapply(BROOD,function(z)HPDI(post$"(Intercept)"+
			post$N7to18.Temp.X*Avg.Temp+post$CI.JDate*Avg.CI+post$Brood.size.d12*z+
			post$TreatmentLONG+post$"Brood.size.d12:TreatmentLONG"*z))
		mu.Low<-sapply(BROOD,function(z)mean(post$"(Intercept)"+
			post$N7to18.Temp.X*Avg.Temp+post$CI.JDate*Avg.CI+post$Brood.size.d12*z+
			post$TreatmentLOW+post$"Brood.size.d12:TreatmentLOW"*z))
		ci.Low<-sapply(BROOD,function(z)HPDI(post$"(Intercept)"+
			post$N7to18.Temp.X*Avg.Temp+post$CI.JDate*Avg.CI+post$Brood.size.d12*z+
			post$TreatmentLOW+post$"Brood.size.d12:TreatmentLOW"*z))
			
		plot(BROOD,mu.Control,type="n",ylim=c(y.low,y.high),xlim=XLIM,
			xlab="Brood Size",ylab=ylaber,main=mainer,xaxt="n",cex.lab=1.5)
		axis(1,at=c(0,2,3,4,5,6,8))
		lines(BROOD,mu.Control,lwd=2,col="black")
		shade(ci.Control,BROOD,col=col.alpha("black",0.1))
		lines(BROOD,mu.DMSO,lwd=2,col="gray40")
		shade(ci.DMSO,BROOD,col=col.alpha("gray40",0.1))
		lines(BROOD,mu.High,lwd=2,col="red")
		shade(ci.High,BROOD,col=col.alpha("red",0.1))
		lines(BROOD,mu.Long,lwd=2,col="slateblue")
		shade(ci.Long,BROOD,col=col.alpha("slateblue",0.1))
		lines(BROOD,mu.Low,lwd=2,col="orange")
		shade(ci.Low,BROOD,col=col.alpha("orange",0.1))
		
		legend("topleft",c("Control","DMSO","Low","High","Long"),
			col=c("black","gray40","orange","red","slateblue"),lwd=2,bty="n")
	}	
	
## Plot models using formula above

	pdf("Output_Nestling_Pheno_Plots.pdf",width=6,height=6)
	plot.n(Fitmods.nmass[[4]],y.low=10,y.high=25,ylaber="Nestling mass (g)",mainer="Nestling mass by brood")		
	#plot.n(Fitmods.condition.headbill[[4]],y.low=10,y.high=25,ylaber="Nestling condition",	
	#	mainer="Nestling condition by brood")	
	plot.n(Fitmods.nflatwing[[4]],y.low=30,y.high=60,ylaber="Nestling wing length (mm)",mainer="Nestling flatwing by brood")	
	#plot.n(Fitmods.Baseline[[4]],y.high=5,ylaber="Nestling base cort",mainer="Nestling base cort by brood")
	#plot.n(Fitmods.Stress[[4]],y.high=5,ylaber="Nestling stress cort",mainer="Nestling stress cort by brood")	
	#plot.n(Fitmods.StressResp[[4]],y.low=0,y.high=5,ylaber="Nestling stress response",
	#	mainer="Nestling stress resp by brood")		
	#plot.n(Fitmods.DexRecovery[[4]],y.low=0,y.high=5,ylaber="Nestling dex recov",mainer="Nestling dex recov by brood")
	#plot.n(Fitmods.DexResp[[4]],y.low=0,y.high=5,ylaber="Nestling dex resp",mainer="Nestling dex resp by brood")			
	dev.off()	
	
## Plot models using formula above but with raw data added

	pdf("Output_Nestling_Pheno_Plots_data.pdf",width=6,height=6)
	plot.n(Fitmods.nmass[[4]],y.low=10,y.high=30,ylaber="Nestling mass (g)",mainer="Nestling mass by brood",XLIM=c(2,6))	
	points(subset(d2$Brood.size.d12,d2$Treatment=="CONTROL")+runif(length(subset(d2$Brood.size.d12,d2$Treatment=="CONTROL")),-0.1,0.1),
		subset(d2$nmass,d2$Treatment=="CONTROL"),pch=16,col="black")	
	points(subset(d2$Brood.size.d12,d2$Treatment=="LONG")+runif(length(subset(d2$Brood.size.d12,d2$Treatment=="LONG")),-0.1,0.1),
		subset(d2$nmass,d2$Treatment=="LONG"),pch=16,col="slateblue")	
	points(subset(d2$Brood.size.d12,d2$Treatment=="HIGH")+runif(length(subset(d2$Brood.size.d12,d2$Treatment=="HIGH")),-0.1,0.1),
		subset(d2$nmass,d2$Treatment=="HIGH"),pch=16,col="red")	
	points(subset(d2$Brood.size.d12,d2$Treatment=="LOW")+runif(length(subset(d2$Brood.size.d12,d2$Treatment=="LOW")),-0.1,0.1),
		subset(d2$nmass,d2$Treatment=="LOW"),pch=16,col="orange")	
	points(subset(d2$Brood.size.d12,d2$Treatment=="DMSO")+runif(length(subset(d2$Brood.size.d12,d2$Treatment=="DMSO")),-0.1,0.1),
		subset(d2$nmass,d2$Treatment=="DMSO"),pch=16,col="gray40")	
	#plot.n(Fitmods.condition.headbill[[4]],y.low=10,y.high=25,ylaber="Nestling condition",	
	#	mainer="Nestling condition by brood")	
	plot.n(Fitmods.nflatwing[[4]],y.low=20,y.high=70,ylaber="Nestling wing length (mm)",mainer="Nestling flatwing by brood",XLIM=c(2,6))	
	points(subset(d2$Brood.size.d12,d2$Treatment=="CONTROL")+runif(length(subset(d2$Brood.size.d12,d2$Treatment=="CONTROL")),-0.1,0.1),
		subset(d2$nflatwing,d2$Treatment=="CONTROL"),pch=16,col="black")	
	points(subset(d2$Brood.size.d12,d2$Treatment=="LONG")+runif(length(subset(d2$Brood.size.d12,d2$Treatment=="LONG")),-0.1,0.1),
		subset(d2$nflatwing,d2$Treatment=="LONG"),pch=16,col="slateblue")	
	points(subset(d2$Brood.size.d12,d2$Treatment=="HIGH")+runif(length(subset(d2$Brood.size.d12,d2$Treatment=="HIGH")),-0.1,0.1),
		subset(d2$nflatwing,d2$Treatment=="HIGH"),pch=16,col="red")	
	points(subset(d2$Brood.size.d12,d2$Treatment=="LOW")+runif(length(subset(d2$Brood.size.d12,d2$Treatment=="LOW")),-0.1,0.1),
		subset(d2$nflatwing,d2$Treatment=="LOW"),pch=16,col="orange")	
	points(subset(d2$Brood.size.d12,d2$Treatment=="DMSO")+runif(length(subset(d2$Brood.size.d12,d2$Treatment=="DMSO")),-0.1,0.1),
		subset(d2$nflatwing,d2$Treatment=="DMSO"),pch=16,col="gray40")	
	#plot.n(Fitmods.Baseline[[4]],y.high=5,ylaber="Nestling base cort",mainer="Nestling base cort by brood")
	#plot.n(Fitmods.Stress[[4]],y.high=5,ylaber="Nestling stress cort",mainer="Nestling stress cort by brood")	
	#plot.n(Fitmods.StressResp[[4]],y.low=0,y.high=5,ylaber="Nestling stress response",
	#	mainer="Nestling stress resp by brood")		
	#plot.n(Fitmods.DexRecovery[[4]],y.low=0,y.high=5,ylaber="Nestling dex recov",mainer="Nestling dex recov by brood")
	#plot.n(Fitmods.DexResp[[4]],y.low=0,y.high=5,ylaber="Nestling dex resp",mainer="Nestling dex resp by brood")			
	dev.off()
	
## Plot models using formula above but with raw data added as a per brood/treatment average

	trs<-c("CONTROL","LONG","HIGH","LOW","DMSO")
	mass.mu<-as.data.frame(matrix(nrow=5,ncol=5))
	colnames(mass.mu)<-c("Two","Three","Four","Five","Six")
	rownames(mass.mu)<-trs
	wing.mu<-mass.mu
	mass.se<-mass.mu
	wing.se<-mass.mu
	mass.n<-mass.mu
	for(i in 1:length(trs)){
		sub1<-subset(d2,d2$Treatment==trs[i])
		for(k in 1:length(trs)){
			mass.mu[i,k]<-mean(na.omit(subset(sub1$nmass,sub1$Brood.size.d12==k+1)))
			wing.mu[i,k]<-mean(na.omit(subset(sub1$nflatwing,sub1$Brood.size.d12==k+1)))
			mass.se[i,k]<-sd(na.omit(subset(sub1$nmass,sub1$Brood.size.d12==k+1)))/
				sqrt(length(na.omit(subset(sub1$nmass,sub1$Brood.size.d12==k+1))))
			wing.se[i,k]<-sd(na.omit(subset(sub1$nflatwing,sub1$Brood.size.d12==k+1)))/
				sqrt(length(na.omit(subset(sub1$nflatwing,sub1$Brood.size.d12==k+1))))
			mass.n[i,k]<-length(na.omit(subset(sub1$nmass,sub1$Brood.size.d12==k+1)))/(k+1)
		}
	}


	pdf("Output_Nestling_Pheno_Plots_avgs1.pdf",width=6,height=6)
	plot.n(Fitmods.nmass[[4]],y.low=10,y.high=30,ylaber="Nestling mass (g)",mainer="Nestling Mass",XLIM=c(2,6))	
	points(seq(2,6,1),mass.mu[1,],pch=16,col=col.alpha("black",0.7),cex=c(1,1.5,0,3,0))
	points(seq(2,6,1),mass.mu[2,],pch=16,col=col.alpha("slateblue",0.7),cex=c(.8,1.5,1.5,1.5,0))
	points(seq(2,6,1),mass.mu[3,],pch=16,col=col.alpha("red",0.7),cex=c(1,1,2,1,.8))
	points(seq(2,6,1),mass.mu[4,],pch=16,col=col.alpha("orange",0.7),cex=c(1,.8,2,1,1.5))
	points(seq(2,6,1),mass.mu[5,],pch=16,col=col.alpha("gray40",0.7),cex=c(0,0,1.5,1.5,.5))
	COLORS<-c("black","slateblue","red","orange","gray40")
	for(i in 1:5){
		for(k in 1:5){
			lines(rep(k+1,2),c(mass.mu[i,k]+mass.se[i,k],mass.mu[i,k]-mass.se[i,k]),col=col.alpha(COLORS[i],0.6),lwd=2)
		}
	}
	points(rep(5.5,3),c(29,28,26.8),cex=c(1,2,3))
	text(5.8,29,"2")
	text(5.8,28,"4")
	text(5.8,26.8,"6")
	text(5.37,29.4,"Sample size (nests)",pos=3)
	#legend("topright",c("6","5","4","3","2","1"),bty="n")
	#plot.n(Fitmods.condition.headbill[[4]],y.low=10,y.high=25,ylaber="Nestling condition",	
	#	mainer="Nestling condition by brood")	
	dev.off()
	
	pdf("Output_Nestling_Pheno_Plots_avgs2.pdf",width=6,height=6)
	plot.n(Fitmods.nflatwing[[4]],y.low=20,y.high=70,ylaber="Nestling wing length (mm)",mainer="Nestling Flatwing",XLIM=c(2,6))	
	points(seq(2,6,1),wing.mu[1,],pch=16,col=col.alpha("black",0.7),cex=c(1,1.5,0,3,0))
	points(seq(2,6,1), wing.mu[2,],pch=16,col=col.alpha("slateblue",0.7),cex=c(.8,1.5,1.5,1.5,0))
	points(seq(2,6,1), wing.mu[3,],pch=16,col=col.alpha("red",0.7),cex=c(1,1,2,1,.8))
	points(seq(2,6,1), wing.mu[4,],pch=16,col=col.alpha("orange",0.7),cex=c(1,.8,2,1,1.5))
	points(seq(2,6,1), wing.mu[5,],pch=16,col=col.alpha("gray40",0.7),cex=c(0,0,1.5,1.5,.5))
	COLORS<-c("black","slateblue","red","orange","gray40")
	for(i in 1:5){
		for(k in 1:5){
			lines(rep(k+1,2),c(wing.mu[i,k]+wing.se[i,k],wing.mu[i,k]-wing.se[i,k]),col=COLORS[i],lwd=2)
		}
	}
	points(rep(5.5,3),c(67,64.5,61.6),cex=c(1,2,3))
	text(5.8,67,"2")
	text(5.8,64.5,"4")
	text(5.8,61.6,"6")
	text(5.44,68,"Sample size (nests)",pos=3)
	#plot.n(Fitmods.Baseline[[4]],y.high=5,ylaber="Nestling base cort",mainer="Nestling base cort by brood")
	#plot.n(Fitmods.Stress[[4]],y.high=5,ylaber="Nestling stress cort",mainer="Nestling stress cort by brood")	
	#plot.n(Fitmods.StressResp[[4]],y.low=0,y.high=5,ylaber="Nestling stress response",
	#	mainer="Nestling stress resp by brood")		
	#plot.n(Fitmods.DexRecovery[[4]],y.low=0,y.high=5,ylaber="Nestling dex recov",mainer="Nestling dex recov by brood")
	#plot.n(Fitmods.DexResp[[4]],y.low=0,y.high=5,ylaber="Nestling dex resp",mainer="Nestling dex resp by brood")			
	dev.off()	











		